=== modified file 'loggerhead/changecache.py'
--- loggerhead/changecache.py	2009-04-24 09:45:31 +0000
+++ loggerhead/changecache.py	2009-04-24 10:30:15 +0000
@@ -40,16 +40,25 @@
 # We take an optimistic approach to concurrency here: we might do work twice
 # in the case of races, but not crash or corrupt data.
 
+def safe_init_db(filename, init_sql):
+    # To avoid races around creating the database, we create the db in
+    # a temporary file and rename it into the ultimate location.
+    fd, temp_path = tempfile.mkstemp(dir=os.path.dirname(filename))
+    con = dbapi2.connect(temp_path)
+    cur = con.cursor()
+    cur.execute(init_sql)
+    con.commit()
+    con.close()
+    os.rename(temp_path, filename)
+
 class FakeShelf(object):
 
     def __init__(self, filename):
         create_table = not os.path.exists(filename)
         if create_table:
-            # To avoid races around creating the database, we create the db in
-            # a temporary file and rename it into the ultimate location.
-            fd, path = tempfile.mkstemp(dir=os.path.dirname(filename))
-            self._create_table(path)
-            os.rename(path, filename)
+            safe_init_db(
+                filename, "create table RevisionData "
+                "(revid binary primary key, data binary)")
         self.connection = dbapi2.connect(filename)
         self.cursor = self.connection.cursor()
 
@@ -108,6 +117,7 @@
 
 
 class RevInfoDiskCache(object):
+    """Like `RevInfoMemoryCache` but backed in a sqlite DB."""
 
     def __init__(self, cache_path):
         if not os.path.exists(cache_path):
@@ -115,26 +125,15 @@
         filename = os.path.join(cache_path, 'revinfo.sql')
         create_table = not os.path.exists(filename)
         if create_table:
-            # To avoid races around creating the database, we create the db in
-            # a temporary file and rename it into the ultimate location.
-            fd, path = tempfile.mkstemp(dir=os.path.dirname(filename))
-            self._create_table(path)
-            os.rename(path, filename)
+            safe_init_db(
+                filename, "create table Data "
+                "(key binary primary key, revid binary, data binary)")
         self.connection = dbapi2.connect(filename)
         self.cursor = self.connection.cursor()
 
-    def _create_table(self, filename):
-        con = dbapi2.connect(filename)
-        cur = con.cursor()
-        cur.execute(
-            "create table Data "
-            "(key binary primary key, revid binary, data binary)")
-        con.commit()
-        con.close()
-
     def get(self, key, revid):
         self.cursor.execute(
-            "select revid, data from data where key = ?", (dbapi2.Binary(key), ))
+            "select revid, data from data where key = ?", (dbapi2.Binary(key),))
         row = self.cursor.fetchone()
         if row is None:
             return None
@@ -156,4 +155,3 @@
             # If another thread or process attempted to set the same key, we
             # don't care too much -- it's only a cache after all!
             pass
-

=== modified file 'loggerhead/history.py'
--- loggerhead/history.py	2009-04-24 09:29:13 +0000
+++ loggerhead/history.py	2009-04-24 10:30:15 +0000
@@ -180,10 +180,27 @@
 
 
 class RevInfoMemoryCache(object):
+    """A store that validates values against the revids they were stored with.
+
+    We use a unique key for each branch.
+
+    The reason for not just using the revid as the key is so that when a new
+    value is provided for a branch, we replace the old value used for the
+    branch.
+
+    There is another implementation of the same interface in
+    loggerhead.changecache.RevInfoDiskCache.
+    """
+
     def __init__(self, cache):
         self._cache = cache
 
     def get(self, key, revid):
+        """Return the data associated with `key`, subject to a revid check.
+
+        If a value was stored under `key`, with the same revid, return it.
+        Otherwise return None.
+        """
         cached = self._cache.get(key)
         if cached is None:
             return None
@@ -194,6 +211,8 @@
             return None
 
     def set(self, key, revid, data):
+        """Store `data` under `key`, to be checked against `revid` on get().
+        """
         self._cache[key] = (revid, data)
 
 
@@ -205,12 +224,32 @@
     around it, serve the request, throw the History object away, unlock the
     branch and throw it away.
 
-    :ivar _file_change_cache:
-    :ivar _rev_info:
+    :ivar _file_change_cache: An object that caches information about the
+        files that changed between two revisions.
+    :ivar _rev_info: A list of information about revisions.  This is by far
+        the most cryptic data structure in loggerhead.  At the top level, it
+        is a list of 3-tuples [(merge-info, where-merged, parents)].
+        `merge-info` is (seq, revid, merge_depth, revno_str, end_of_merge) --
+        like a merged sorted list, but the revno is stringified.
+        `where-merged` is a tuple of revisions that have this revision as a
+        non-lefthand parent.  Finally, `parents` is just the usual list of
+        parents of this revision.
+    :ivar _rev_indices: A dictionary mapping each revision id to the index of
+        the information about it in _rev_info.
+    :ivar _full_history: A list of all revision ids in the ancestry of the
+        branch, in merge-sorted order.  This is a bit silly, and shouldn't
+        really be stored on the instance...
+    :ivar _revno_revid: A dictionary mapping stringified revnos to revision
+        ids.
     """
 
     def _load_whole_history_data(self, caches, cache_key):
-        """XXX Write this!"""
+        """Set the attributes relating to the whole history of the branch.
+
+        :param caches: a list of caches with interfaces like
+            `RevInfoMemoryCache` and be ordered from fastest to slowest.
+        :param cache_key: the key to use with the caches.
+        """
         self._rev_indices = None
         self._rev_info = None
 

=== modified file 'loggerhead/wholehistory.py'
--- loggerhead/wholehistory.py	2009-04-24 05:37:45 +0000
+++ loggerhead/wholehistory.py	2009-04-24 10:30:15 +0000
@@ -37,6 +37,10 @@
 
 
 def compute_whole_history_data(branch):
+    """Compute _rev_info and _rev_indices for a branch.
+
+    See History.__doc__ for what these data structures mean.
+    """
     z = time.time()
 
     last_revid = branch.last_revision()

